**********
References
**********

.. [Bie16] Bierman, A. *Guidelines for Authors and Reviewers of YANG
       Data Model Documents*. `draft-ietf-netmod-rfc6087bis`__,
       IETF, 2016.

__ https://tools.ietf.org/html/draft-ietf-netmod-rfc6087bis

.. [Hue97] Huet, G. The Zipper. *J. Functional Programming* **7** (5):
       549–554, 1997. Available online__.

__ http://gallium.inria.fr/~huet/PUBLIC/zip.pdf

.. [PEP484] van Rossum, G.; Lehtosalo, J.; Langa, Ł. *Type Hints.*
        `PEP 484`__, Python Software Foundation, 2014.

__ https://www.python.org/dev/peps/pep-0484

.. [RFC6241] Enns R. (ed.) et al. *Network Configuration Protocol
         (NETCONF).* `RFC 6241`__, IETF, 2011, 113 p. ISSN
         2070-1721.

__ https://tools.ietf.org/html/rfc6241

.. [RFC6536] Bierman, A.; Bjorklund, M. *Network Configuration
         Protocol (NETCONF) Access Control Model.* `RFC 6536`__,
         IETF, 2012, 49 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc6536

.. [RFC6901] Bryan, P. (ed.); Zyp, K.; Nottingham, M. *JavaScript
         Object Notation (JSON) Pointer*. `RFC 6901`__,
         IETF, 2013. 8 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc6901

.. [RFC7895] Bierman, A.; Bjorklund, M.; Watsen, K. *YANG Module
         Library.* `RFC 7895`__, IETF, 2016. 13 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc7895

.. [RFC7950] Bjorklund, M. (ed.). *The YANG 1.1 Data Modeling Language.*
         `RFC 7950`__, IETF, August 2016. 217 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc7950

.. [RFC7951] Lhotka, L. *JSON Encoding of Data Modeled with YANG.*
       `RFC 7951`__, IETF, August 2016. 20 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc7951

.. [RFC7952] Lhotka, L. *Defining and Using Metadata with YANG.*
       `RFC 7952`__, IETF, August 2016. 20 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc7952

.. [RFC8040] Bierman, A.; Bjorklund, M.; Watsen, K. *RESTCONF Protocol.*
       `RFC 8040`__, IETF, 2017. 137 p. ISSN 2070-1721.

__ https://tools.ietf.org/html/rfc8040

.. [XPath] Clark, J.; DeRose S. *XML Path Language (XPath) Version
       1.0*. W3C Recommendation `REC-xpath-19991116`__, World Wide
       Web Consortium, 1999.

__ http://www.w3.org/TR/1999/REC-xpath-19991116/
